@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
 
-from PySide2.QtGui import QImage, QPixmap
+from PySide6.QtGui import QImage, QPixmap
 
 from nodedge.graphics_node import GraphicsNode
 
@@ -12,7 +12,7 @@ class GraphicsBlock(GraphicsNode):
         super().initSizes()
         self.width = 200
         self.height = 80
-        self.edgeRoundness = 0.0
+        self.edgeRoundness = 2.0
         self.edgePadding = 0.0
         self.titleHorizontalPadding = 8.0
         self.titleVerticalPadding = 18.0
@@ -21,7 +21,7 @@ class GraphicsBlock(GraphicsNode):
     def initStyle(self):
         super().initStyle()
         self.icons = QImage(
-            f"{os.path.dirname(__file__)}/../resources/node_icons/status_icons.png"
+            f"{os.path.dirname(__file__)}/../../resources/node_icons/status_icons.png"
         )
 
     def paint(self, painter, QStyleOptionGraphicsItem, widget=None):
