@@ -13,10 +13,13 @@ from nodedge.graphics_edge import (
     GraphicsEdgeBezier,
     GraphicsEdgeCircuit,
     GraphicsEdgeDirect,
+    GraphicsEdgeSmartCircuit,
 )
 from nodedge.serializable import Serializable
 from nodedge.utils import dumpException
 
+logger = logging.getLogger(__name__)
+
 
 class EdgeType(IntEnum):
     """
@@ -26,6 +29,7 @@ class EdgeType(IntEnum):
     STRAIGHT = 1  #:
     BEZIER = 2  #:
     CIRCUIT = 3  #:
+    SMART_CIRCUIT = 4  #:
 
 
 class Edge(Serializable):
@@ -67,9 +71,6 @@ class Edge(Serializable):
 
         super().__init__()
 
-        self.__logger = logging.getLogger(__file__)
-        self.__logger.setLevel(logging.INFO)
-
         # Default initialization
         self._sourceSocket: Optional[Socket] = None
         self._targetSocket: Optional[Socket] = None
@@ -164,8 +165,10 @@ class Edge(Serializable):
             self.graphicsEdge: GraphicsEdge = GraphicsEdgeDirect(self)
         elif self.edgeType == EdgeType.BEZIER:
             self.graphicsEdge = GraphicsEdgeBezier(self)
-        else:
+        elif self.edgeType == EdgeType.CIRCUIT:
             self.graphicsEdge = GraphicsEdgeCircuit(self)
+        else:
+            self.graphicsEdge = GraphicsEdgeSmartCircuit(self)
         self.scene.graphicsScene.addItem(self.graphicsEdge)
 
         if self.sourceSocket is not None:
@@ -204,7 +207,6 @@ class Edge(Serializable):
             )
             if self.graphicsEdge is not None:
                 self.graphicsEdge.sourcePos = sourcePos
-        # TODO: simplify terminology: end -> target | start -> source
 
         if self.targetSocket is not None:
             targetPos = (
@@ -217,8 +219,8 @@ class Edge(Serializable):
                 if sourcePos is not None:
                     self.graphicsEdge.targetPos = sourcePos
 
-        self.__logger.debug(f"Start socket: {self.sourceSocket}")
-        self.__logger.debug(f"End socket: {self.targetSocket}")
+        logger.debug(f"Start socket: {self.sourceSocket}")
+        logger.debug(f"End socket: {self.targetSocket}")
         if self.graphicsEdge is not None:
             self.graphicsEdge.update()
 
@@ -243,8 +245,6 @@ class Edge(Serializable):
         """
         Set start and end :class:`~nodedge.socket.Socket` to ``None``
         """
-
-        # TODO: Is it meaningful?
         self.targetSocket = None
         self.sourceSocket = None
 
@@ -273,21 +273,21 @@ class Edge(Serializable):
         if self.graphicsEdge is not None:
             self.graphicsEdge.hide()
 
-        self.__logger.debug(f"Removing {self} from all sockets.")
+        logger.debug(f"Removing {self} from all sockets.")
         self.removeFromSockets()
 
-        self.__logger.debug(f"Removing Graphical edge: {self.graphicsEdge}")
+        logger.debug(f"Removing Graphical edge: {self.graphicsEdge}")
         self.scene.graphicsScene.removeItem(self.graphicsEdge)
         self.scene.graphicsScene.update()
         self.graphicsEdge = None  # type: ignore
 
-        self.__logger.debug(f"Removing {self}")
+        logger.debug(f"Removing {self}")
         try:
             self.scene.removeEdge(self)
         except ValueError as e:
-            self.__logger.debug(e)
+            logger.debug(e)
 
-        self.__logger.debug("Edge has been deleted.")
+        logger.debug("Edge has been deleted.")
 
         # Notify nodes from old sockets
         try:
