@@ -7,9 +7,9 @@ import logging
 import os
 from typing import List, Optional
 
-from PySide2.QtCore import Qt
-from PySide2.QtGui import QBrush, QMouseEvent, QPen
-from PySide2.QtWidgets import (
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QBrush, QMouseEvent, QPen
+from PySide6.QtWidgets import (
     QApplication,
     QGraphicsItem,
     QLabel,
@@ -83,7 +83,7 @@ class EditorWidget(QWidget):
 
         :rtype: ``bool``
         """
-        return self.filename is not None
+        return self.filename != ""
 
     @property
     def shortName(self) -> str:
@@ -180,6 +180,19 @@ class EditorWidget(QWidget):
         """
         QApplication.setOverrideCursor(Qt.WaitCursor)
         try:
+            if not os.path.exists(filename):
+                QApplication.restoreOverrideCursor()
+                ok = QMessageBox.warning(
+                    self,
+                    "File not found",
+                    f"File {filename} does not exist. \n"
+                    "Do you want to open a new file?",
+                    QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Cancel,
+                )
+                if ok == QMessageBox.StandardButton.Ok:
+                    self.newFile()
+                else:
+                    raise FileNotFoundError(f"File {filename} not found.")
             self.scene.loadFromFile(filename)
             self.filename = filename
             # Don't store initial stamp because the file has still not been changed.
@@ -188,13 +201,8 @@ class EditorWidget(QWidget):
             self.evalNodes()
             return True
         except FileNotFoundError as e:
-            self.__logger.warning(f"File {filename} not found: {e}")
+            self.__logger.warning(e)
             dumpException(e)
-            QMessageBox.warning(
-                self,
-                "Error loading %s" % os.path.basename(filename),
-                str(e).replace("[Errno 2]", ""),
-            )
             return False
         except InvalidFile as e:
             self.__logger.warning(f"Error loading {filename}: {e}")
@@ -233,7 +241,7 @@ class EditorWidget(QWidget):
 
     def mouseReleaseEvent(self, ev: QMouseEvent) -> None:
         """
-        Handle Qt's mouse's button release event.
+        Handle Qt mouse's button release event.
 
         :param ev: Mouse release event
         :type ev: ``QMouseEvent``
@@ -243,7 +251,7 @@ class EditorWidget(QWidget):
 
     def mousePressEvent(self, ev: QMouseEvent) -> None:
         """
-        Handle Qt's mouse's button press event.
+        Handle Qt mouse's button press event.
 
         :param ev: Mouse press event
         :type ev: ``QMouseEvent``
