@@ -5,22 +5,31 @@ Editor window module containing :class:`~nodedge.editor_window.EditorWindow` cla
 import json
 import logging
 import os
-from typing import Callable, Optional, Union, cast
+from typing import Callable, List, Optional, Union, cast
 
-from PySide2.QtCore import QPoint, QSettings, QSize, Qt
-from PySide2.QtGui import QClipboard, QCloseEvent, QGuiApplication, QKeySequence
-from PySide2.QtWidgets import (
+from PySide6.QtCore import QSettings, QSize, QStandardPaths, Qt, Signal
+from PySide6.QtGui import (
     QAction,
+    QClipboard,
+    QCloseEvent,
+    QGuiApplication,
+    QKeySequence,
+)
+from PySide6.QtWidgets import (
+    QDialog,
     QFileDialog,
     QLabel,
     QMainWindow,
     QMenu,
     QMessageBox,
+    QTextEdit,
+    QVBoxLayout,
     QWidget,
 )
 
-from nodedge.application_styler import ApplicationStyler
 from nodedge.editor_widget import EditorWidget
+from nodedge.scene_coder import SceneCoder
+from nodedge.solver_dialog import SolverDialog
 
 
 class EditorWindow(QMainWindow):
@@ -37,6 +46,8 @@ class EditorWindow(QMainWindow):
 
     EditorWidgetClass = EditorWidget
 
+    recentFilesUpdated = Signal(object)
+
     def __init__(self, parent: Optional[QWidget] = None):
         """
         :Instance Attributes:
@@ -51,23 +62,23 @@ class EditorWindow(QMainWindow):
         self.__logger.setLevel(logging.INFO)
 
         self.companyName = "Nodedge"
-        self.productName = "Editor"
+        self.productName = "Nodedge"
 
         self.instance: QGuiApplication = cast(
             QGuiApplication, QGuiApplication.instance()
         )
 
-        self.styler = ApplicationStyler()
+        # self.styler = ApplicationStyler()
 
         self.clipboard: QClipboard = self.instance.clipboard()
 
         # Pycharm does not recognise resolve connect method so the inspection is
         # noinspection PyUnresolvedReferences
-        self.clipboard.dataChanged.connect(self.onClipboardChanged)
+        self.clipboard.dataChanged.connect(self.onClipboardChanged)  # type: ignore
 
         self.lastActiveEditorWidget: Optional[EditorWidget] = None
-
         self.debugMode: bool = False
+        self.recentFiles: List[str] = []
 
         self.initUI()
 
@@ -129,7 +140,7 @@ class EditorWindow(QMainWindow):
         if self.currentEditorWidget is None:
             return
 
-        self.currentEditorWidget.graphicsView.scenePosChanged.connect(  # type: ignore
+        self.currentEditorWidget.graphicsView.scenePosChanged.connect(
             self.OnScenePosChanged
         )
 
@@ -183,10 +194,10 @@ class EditorWindow(QMainWindow):
             "&Delete", self.delete, "Delete selected items", QKeySequence("Del")
         )
 
-        self.fitInViewAct = self.createAction(
-            "Fit in view",
-            self.onFitInView,
-            "Fit content in view",
+        self.fitToViewAct = self.createAction(
+            "Fit to view",
+            self.onFitToView,
+            "Fit content to view",
             QKeySequence(Qt.Key_Space),
         )
 
@@ -197,6 +208,92 @@ class EditorWindow(QMainWindow):
             QKeySequence("Ctrl+G"),
         )
 
+        self.configureSolverAct = self.createAction(
+            "Configure solver",
+            self.configureSolver,
+            "Configure solver",
+            QKeySequence("Ctrl+K"),
+        )
+
+        self.showCodeAct = self.createAction(
+            "Show code",
+            self.onShowCode,
+            "Show python code",
+            QKeySequence("Ctrl+Shift+C"),
+        )
+        self.showCodeAct.setEnabled(False)
+
+        self.showGraphAct = self.createAction(
+            "Show graph",
+            self.onShowGraph,
+            "Show graph",
+            QKeySequence("Ctrl+Shift+G"),
+        )
+        self.showGraphAct.setEnabled(False)
+
+        self.evalAct = self.createAction(
+            "Eval all nodes", self.evaluateAllNodes, "", QKeySequence("Ctrl+Space")
+        )
+
+        self.simulateAct = self.createAction(
+            "Simulate",
+            self.onSimulate,
+            "Simulate",
+            QKeySequence("Ctrl+Shift+S"),
+        )
+
+        self.takeScreenShotAct = self.createAction(
+            "Take screenShot",
+            self.takeScreenshot,
+            "Take screenShot",
+            QKeySequence("Ctrl+Shift+Space"),
+        )
+
+    def takeScreenshot(self, filename=None):
+        """
+        Take screenShot
+        """
+        self.__logger.debug("Take screenShot")
+        if filename is None:
+            filename, _ = QFileDialog.getSaveFileName(
+                parent=self,
+                caption="Save graph to file",
+                dir=EditorWindow.getFileDialogDirectory(),
+                filter="PNG (*.png);; JPG (*.jpg);; JPEG (*.jpeg)",
+            )
+
+        if not filename:
+            return
+
+        self.currentEditorWidget.scene.graphicsView.grab().save(filename)
+
+    def onSimulate(self):
+        self.currentEditorWidget.scene.simulator.run()
+
+    def onShowGraph(self):
+        QMessageBox.information(self, "Graph", "Show graph")
+
+    def onShowCode(self):
+        """
+        Show the generated code.
+        """
+
+        dialog = QDialog(self)
+        dialog.setMinimumWidth(600)
+        dialog.setWindowTitle("Code")
+        dialog.setLayout(QVBoxLayout())
+        dialog.layout().addWidget(QLabel(f"{self.currentEditorWidget.shortName} code:"))
+        codeEdit = QTextEdit()
+        codeEdit.setReadOnly(True)
+        codeEdit.setPlainText(self.currentEditorWidget.scene.coder.generatedCode)
+        dialog.layout().addWidget(codeEdit)
+
+        dialog.showMaximized()
+
+    def evaluateAllNodes(self):
+        for n in self.editorWidget.scene.nodes:
+            n.eval()
+
     # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
     def createMenus(self) -> None:
         """
@@ -206,11 +303,31 @@ class EditorWindow(QMainWindow):
         self.createEditMenu()
         self.createViewMenu()
         self.createCoderMenu()
+        self.createSimulationMenu()
+
+    def createSimulationMenu(self) -> None:
+        """
+        Create the simulation menu.
+        """
+        self.simMenu: QMenu = self.menuBar().addMenu("&Simulation")
+        self.simMenu.addAction(self.configureSolverAct)
+        self.simMenu.addAction(self.showGraphAct)
+        self.simMenu.addAction(self.simulateAct)
+        self.simMenu.addAction(self.evalAct)
 
     # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
     def createCoderMenu(self):
         self.coderMenu: QMenu = self.menuBar().addMenu("&Coder")
         self.coderMenu.addAction(self.generateCodeAct)
+        self.coderMenu.addAction(self.showCodeAct)
+
+    def configureSolver(self):
+        simulatorConfig = self.currentEditorWidget.scene.simulator.config
+        self.solverDialog = SolverDialog(simulatorConfig)
+        self.solverDialog.solverConfigChanged.connect(
+            self.currentEditorWidget.scene.simulator.updateConfig
+        )
+        self.solverDialog.show()
 
     # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
     def createFileMenu(self):
@@ -221,11 +338,28 @@ class EditorWindow(QMainWindow):
         self.fileMenu.addAction(self.newAct)
         self.fileMenu.addSeparator()
         self.fileMenu.addAction(self.openAct)
+        self.recentFilesMenu = self.fileMenu.addMenu("Open recent")
+        self.updateRecentFilesMenu()
         self.fileMenu.addAction(self.saveAct)
         self.fileMenu.addAction(self.saveAsAct)
         self.fileMenu.addSeparator()
+        self.fileMenu.addAction(self.takeScreenShotAct)
+        self.fileMenu.addSeparator()
         self.fileMenu.addAction(self.quitAct)
 
+    def updateRecentFilesMenu(self):
+        self.recentFilesMenu.clear()
+        for index, filePath in enumerate(self.recentFiles):
+            shortpath = filePath.replace("\\", "/")
+            shortpath = filePath.split("/")[-1]
+            action = self.createAction(
+                shortpath,
+                lambda: self.openFile(filePath),
+                f"Open {filePath}",
+                QKeySequence(f"Ctrl+Shift+{1}"),
+            )
+            self.recentFilesMenu.addAction(action)
+
     # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
     def createEditMenu(self):
         """
@@ -247,11 +381,11 @@ class EditorWindow(QMainWindow):
         Create view menu.
         """
         self.viewMenu: QMenu = self.menuBar().addMenu("&View")
-        self.viewMenu.addAction(self.fitInViewAct)
+        self.viewMenu.addAction(self.fitToViewAct)
 
     def sizeHint(self) -> QSize:
         """
-        Qt's size hint handle.
+        Qt size hint handle.
         TODO: Investigate if we really need to overwrite this method.
 
         :return: ``None``
@@ -275,6 +409,7 @@ class EditorWindow(QMainWindow):
             self.setWindowTitle(title)
 
             self.currentEditorWidget.updateTitle()
+            self.showCodeAct.setEnabled(False)
 
     def onClipboardChanged(self) -> None:
         """
@@ -317,7 +452,7 @@ class EditorWindow(QMainWindow):
         self.__logger.debug("Opening graph")
         if self.maybeSave():
             if filename is None:
-                filename, _ = QFileDialog.getOpenFileName(
+                filename, ok = QFileDialog.getOpenFileName(
                     parent=self,
                     caption="Open graph from file",
                     dir=EditorWindow.getFileDialogDirectory(),
@@ -325,7 +460,7 @@ class EditorWindow(QMainWindow):
                 )
 
             if filename == "":
-                return
+                self.newFile()
             if os.path.isfile(filename):
                 self.currentEditorWidget.loadFile(filename)
                 self.statusBar().showMessage(
@@ -334,22 +469,83 @@ class EditorWindow(QMainWindow):
 
                 self.updateTitle()
 
+        self.fitToViewAct.trigger()
+
     def saveFile(self):
         """
         Save serialized JSON version of the currently opened file, in a JSON file
         based on the editor's filename.
         """
-        self.__logger.debug("Saving graph")
+        self.__logger.warning("Saving graph")
         if not self.currentEditorWidget.hasName:
             self.saveFileAs()
 
-        self.currentEditorWidget.saveFile(self.currentEditorWidget.filename)
-        self.statusBar().showMessage(
-            f"Successfully saved to {self.currentEditorWidget.shortName}", 5000
-        )
+        else:
+            self.currentEditorWidget.saveFile(self.currentEditorWidget.filename)
+
+        if self.currentEditorWidget.hasName:
+            self.saveSnapshot()
+            self.addToRecentFiles(self.currentEditorWidget.filename)
+
+            self.statusBar().showMessage(
+                f"Successfully saved to {self.currentEditorWidget.shortName}", 5000
+            )
+        else:
+            self.statusBar().showMessage(f"Save aborted", 5000)
         self.updateTitle()
         self.currentEditorWidget.updateTitle()
 
+    def saveSnapshot(self):
+        data_path = QStandardPaths.writableLocation(QStandardPaths.AppDataLocation)
+        filename = self.currentEditorWidget.filename
+        filename = filename.replace("\\", "_")
+        filename = filename.replace("/", "_")
+        filename = filename.replace(":", "_")
+        filename = filename.replace(".json", "")
+
+        filePath = os.path.join(data_path, filename + ".png")
+
+        if not os.path.exists(data_path):
+            os.makedirs(data_path)
+
+        # self.onFitInView()
+        self.currentEditorWidget.graphicsView.graphicsScene.fitToView()
+        self.takeScreenshot(filePath)
+
+    def addToRecentFiles(self, filepath):
+        """
+        Add to the recent files list.
+
+        :param filepath: absolute path and filename of the file to open.
+        :type filepath: ``str``
+        """
+        if filepath in self.recentFiles:
+            self.recentFiles.remove(filepath)
+        self.recentFiles.insert(0, filepath)
+
+        if len(self.recentFiles) > 10:
+            self.recentFiles.pop()
+
+        self.writeRecentFilesSettings()
+        self.updateRecentFilesMenu()
+
+        self.recentFilesUpdated.emit(self.recentFiles)
+
+    def removeFromRecentFiles(self, filePath: str):
+        """
+        Remove from the recent files list.
+
+        :param filePath: absolute path and filename of the file to open.
+        :type filePath: ``str``
+        """
+        if filePath in self.recentFiles:
+            self.recentFiles.remove(filePath)
+
+        self.writeRecentFilesSettings()
+        self.updateRecentFilesMenu()
+
+        self.recentFilesUpdated.emit(self.recentFiles)
+
     def saveFileAs(self):
         """
         Save serialized JSON version of the currently opened file, allowing the user
@@ -363,7 +559,7 @@ class EditorWindow(QMainWindow):
             filter=EditorWindow.getFileDialogFilter(),
         )
 
-        if filename == "":
+        if filename in [None, "", ""]:
             return
 
         self.beforeSaveFileAs(self.currentEditorWidget, filename)
@@ -466,7 +662,13 @@ class EditorWindow(QMainWindow):
         :return: starting directory for ``QFileDialog`` file open/save
         :rtype: ``str``
         """
-        return ""
+        settings = QSettings("Nodedge", "Nodedge")
+
+        defaultWorkspacePath = QStandardPaths.writableLocation(
+            QStandardPaths.DocumentsLocation
+        )
+        workspacePath = str(settings.value("workspacePath", defaultWorkspacePath))
+        return workspacePath
 
     @staticmethod
     def getFileDialogFilter() -> str:
@@ -495,12 +697,14 @@ class EditorWindow(QMainWindow):
             self,
             "Nodedge is about to close",
             "There are unsaved modifications. \n" "Do you want to save your changes?",
-            QMessageBox.Save | QMessageBox.Discard | QMessageBox.Cancel,
+            QMessageBox.StandardButton.Save
+            | QMessageBox.StandardButton.Discard
+            | QMessageBox.StandardButton.Cancel,
         )
 
-        if res == QMessageBox.Save:
+        if res == QMessageBox.StandardButton.Save:
             return self.saveFile()
-        elif res == QMessageBox.Cancel:
+        elif res == QMessageBox.StandardButton.Cancel:
             return False
 
         return True
@@ -512,7 +716,14 @@ class EditorWindow(QMainWindow):
         settings = QSettings(self.companyName, self.productName)
         self.restoreGeometry(settings.value("geometry"))
         self.restoreState(settings.value("windowState"))
-        self.debugMode = settings.value("debug", False)
+        debugMode = settings.value("debug", False)
+        if debugMode == "false":
+            self.debugMode = False
+        elif debugMode == "true":
+            self.debugMode = True
+        else:
+            self.debugMode = debugMode
+        self.recentFiles = list(settings.value("recent_files", []))
 
     def writeSettings(self):
         """
@@ -523,6 +734,15 @@ class EditorWindow(QMainWindow):
         settings.setValue("windowState", self.saveState())
         settings.setValue("debug", self.debugMode)
 
+        self.writeRecentFilesSettings()
+
+    def writeRecentFilesSettings(self):
+        """
+        Write the recent files settings for this application.
+        """
+        settings = QSettings(self.companyName, self.productName)
+        settings.setValue("recent_files", self.recentFiles)
+
     def beforeSaveFileAs(
         self, currentEditorWidget: EditorWidget, filename: str
     ) -> None:
@@ -540,13 +760,19 @@ class EditorWindow(QMainWindow):
         """
         pass
 
-    def onFitInView(self):
+    def onFitToView(self):
         if self.currentEditorWidget is not None:
-            self.currentEditorWidget.graphicsView.graphicsScene.fitInView()
+            self.currentEditorWidget.graphicsView.graphicsScene.fitToView()
 
     def onGenerateCode(self):
         if self.currentEditorWidget is not None:
-            self.currentEditorWidget.scene.coder.generateCode()
+            coder: SceneCoder = self.currentEditorWidget.scene.coder
+            if coder is not None:
+                self.currentEditorWidget.scene.coder.generateCodeAndSave()
+                successStr = f"File saved to {coder.filename}"
+                self.__logger.debug(successStr)
+                self.statusBar().showMessage(successStr, 5000)
+                self.showCodeAct.setEnabled(True)
 
     def createAction(
         self,
@@ -554,6 +780,7 @@ class EditorWindow(QMainWindow):
         callback: Callable,
         statusTip: Optional[str] = None,
         shortcut: Union[None, str, QKeySequence] = None,
+        checkable: bool = False,
     ) -> QAction:
         """
         Create an action for this window and add it to actions list.
@@ -567,9 +794,11 @@ class EditorWindow(QMainWindow):
         :type statusTip: Optional[``str``]
         :param shortcut: Keyboard shortcut to trigger the action.
         :type shortcut: ``Optional[str]``
+        :param checkable: if checkable, a mark will appear near the action in the menu when active.
+        :type checkable: ``bool``
         :return:
         """
-        act = QAction(name, self)
+        act = QAction(parent=self, text=name, checkable=checkable)  # type: ignore
         act.triggered.connect(callback)
 
         if statusTip is not None:
@@ -581,4 +810,4 @@ class EditorWindow(QMainWindow):
 
         self.addAction(act)
 
-        return act
+        return act  # type: ignore
