@@ -6,9 +6,9 @@ Graphics node module containing :class:`~nodedge.graphics_node.GraphicsNode` cla
 import logging
 from typing import Optional, cast
 
-from PySide2.QtCore import QRectF, Qt
-from PySide2.QtGui import QBrush, QColor, QFont, QPainterPath, QPen
-from PySide2.QtWidgets import (
+from PySide6.QtCore import QRectF, Qt
+from PySide6.QtGui import QBrush, QColor, QFont, QPainterPath, QPen
+from PySide6.QtWidgets import (
     QApplication,
     QFrame,
     QGraphicsItem,
@@ -129,7 +129,7 @@ class GraphicsNode(QGraphicsItem):
         self._penSelected.setWidthF(2.0)
 
         self._penHovered: QPen = QPen(self._colorHovered)
-        self._penHovered.setWidthF(2.0)
+        self._penHovered.setWidthF(4.0)
 
         self._brushTitle: QBrush = QBrush(QColor("#FF313131"))
         self._brushBackground: QBrush = QBrush(QColor("#E3212121"))
@@ -165,9 +165,11 @@ class GraphicsNode(QGraphicsItem):
             widget.setLayout(layout)
 
             titleFrame = GraphicsNodeTitleFrame(widget)
+            titleFrame.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+            titleFrame.setMaximumWidth(200)
             titleFrame.setMaximumHeight(30)
             titleLayout = QHBoxLayout()
-            titleLayout.setMargin(0)
+            titleLayout.setContentsMargins(0, 0, 0, 0)
             titleFrame.setLayout(titleLayout)
             self.titleLabel = GraphicsNodeTitleLabel(self.title, widget)
             self.titleLabel.setSizePolicy(
@@ -256,7 +258,7 @@ class GraphicsNode(QGraphicsItem):
 
     def mouseMoveEvent(self, event):
         """
-        Override Qt's event to detect that we moved this .
+        Override Qt event to detect that we moved this .
         """
         super().mouseMoveEvent(event)
 
@@ -270,7 +272,7 @@ class GraphicsNode(QGraphicsItem):
 
     def mouseReleaseEvent(self, event):
         """
-        Handle Qt's event when we move, select or deselect this
+        Handle Qt event when we move, select or deselect this
         :class:`~nodedge.graphics_node.GraphicsNode`.
         """
         super().mouseReleaseEvent(event)
@@ -278,14 +280,22 @@ class GraphicsNode(QGraphicsItem):
         # Handle when node moved
         if self._wasMoved:
             clipSize = self.node.scene.graphicsScene.gridSize
+            halfClipSize = round(clipSize / 2)
             pos = event.scenePos() - event.pos()
-            newX = pos.x() - pos.x() % clipSize
-            newY = pos.y() - pos.y() % clipSize
+            xRest = pos.x() % clipSize
+            yRest = pos.y() % clipSize
+
+            dx, dy = -xRest, -yRest
+            if xRest > halfClipSize:
+                dx += clipSize
+            if yRest > halfClipSize:
+                dy += clipSize
 
-            self.setPos(newX, newY)
             graphicsScene: GraphicsScene = cast(GraphicsScene, self.scene())
             for node in graphicsScene.scene.nodes:
                 if node.graphicsNode.isSelected():
+                    nodePos = node.graphicsNode.pos()
+                    node.graphicsNode.setPos(nodePos.x() + dx, nodePos.y() + dy)
                     node.updateConnectedEdges()
 
             self.__logger.debug(f"Current graphics node pos: {self.pos()}")
@@ -315,7 +325,7 @@ class GraphicsNode(QGraphicsItem):
 
     def hoverEnterEvent(self, event: QGraphicsSceneHoverEvent) -> None:
         """
-        Handle Qt's hover event.
+        Handle Qt hover event.
         It adds a highlighting boundary around this
         :class:`~nodedge.graphics_node.GraphicsNode`.
         """
@@ -324,14 +334,14 @@ class GraphicsNode(QGraphicsItem):
 
     def hoverLeaveEvent(self, event: QGraphicsSceneHoverEvent) -> None:
         """
-        Handle Qt's hover effect.
+        Handle Qt hover effect.
         """
         self.hovered = False
         self.update()
 
     def mouseDoubleClickEvent(self, event: QGraphicsSceneMouseEvent):
         """
-        Qt's overridden event for doubleclick.
+        Qt overridden event for doubleclick.
         Resend to :func:`~nodedge.node.Node.onDoubleClicked`
         """
         self.node.onDoubleClicked(event)
