@@ -2,14 +2,14 @@
 """
 Graphics scene module containing :class:`~nodedge.graphics_scene.GraphicsScene` class.
 """
-
 import logging
 from math import ceil, floor, log
 from typing import Optional
 
-from PySide2.QtCore import QLine, Qt, Signal
-from PySide2.QtGui import QColor, QMatrix, QPen, QTransform
-from PySide2.QtWidgets import (
+from PySide6.QtCore import QLine, QPointF, Qt, Signal
+from PySide6.QtGui import QPen, QTransform
+from PySide6.QtWidgets import (
+    QApplication,
     QGraphicsItem,
     QGraphicsItemGroup,
     QGraphicsScene,
@@ -18,6 +18,8 @@ from PySide2.QtWidgets import (
     QWidget,
 )
 
+logger = logging.getLogger(__name__)
+
 
 class GraphicsScene(QGraphicsScene):
     """:class:`~nodedge.scene.Scene` class
@@ -31,6 +33,8 @@ class GraphicsScene(QGraphicsScene):
 
     itemsPressed = Signal(list)
 
+    mouseMoved = Signal(QPointF)
+
     def __init__(
         self, scene: "Scene", parent: Optional[QWidget] = None  # type: ignore
     ) -> None:
@@ -43,9 +47,6 @@ class GraphicsScene(QGraphicsScene):
 
         super().__init__(parent)
 
-        self.__logger = logging.getLogger(__file__)
-        self.__logger.setLevel(logging.INFO)
-
         self.scene = scene
         self.initUI()
 
@@ -58,13 +59,14 @@ class GraphicsScene(QGraphicsScene):
     # noinspection PyAttributeOutsideInit
     def initStyle(self) -> None:
         """Initialize ``QObjects`` like ``QColor``, ``QPen`` and ``QBrush``"""
-        self._colorBackground = QColor("#363A46")
-        self._colorLight = QColor("#666666")
-        self._colorDark = QColor("#999999")
+        p = QApplication.palette()
+        self._colorBackground = p.base().color()
+        self._colorSmallSquares = p.linkVisited().color()
+        self._colorBigSquares = p.link().color()
 
-        self._penSmallSquares = QPen(self._colorLight, 0.3, Qt.DotLine)
+        self._penSmallSquares = QPen(self._colorSmallSquares, 0.3, Qt.DotLine)
 
-        self._penBigSquares = QPen(self._colorDark, 0.6)
+        self._penBigSquares = QPen(self._colorBigSquares, 0.6)
         self._penBigSquares.setDashPattern([2, 6])
 
     # noinspection PyAttributeOutsideInit
@@ -122,7 +124,7 @@ class GraphicsScene(QGraphicsScene):
 
     def dragMoveEvent(self, event: QGraphicsSceneDragDropEvent) -> None:
         """
-        Handle Qt's mouse's drag move event.
+        Handle Qt mouse's drag move event.
 
         :param event: Mouse release event
         :type event: ``QGraphicsSceneDragDropEvent.py``
@@ -131,12 +133,13 @@ class GraphicsScene(QGraphicsScene):
 
     def mousePressEvent(self, event: QGraphicsSceneMouseEvent) -> None:
         """
-        Handle Qt's mouse's button press event.
+        Handle Qt mouse's button press event.
 
         :param event: Mouse release event
         :type event: ``QGraphicsSceneMouseEvent.py``
         """
         item: Optional[QGraphicsItem] = self.itemAt(event.scenePos(), QTransform())
+        logger.debug(f"item: {item}")
 
         if (
             item is not None
@@ -144,20 +147,19 @@ class GraphicsScene(QGraphicsScene):
             and item.parentItem() not in self.selectedItems()
             and not event.modifiers() & Qt.ShiftModifier
         ):
-            self.__logger.debug(f"Pressed item: {item}")
-            self.__logger.debug(f"Pressed parent item: {item.parentItem()}")
-            self.__logger.debug(
-                f"Selected items in graphics scene: {self.selectedItems()}"
-            )
+            logger.debug(f"Pressed item: {item}")
+            logger.debug(f"Pressed parent item: {item.parentItem()}")
+            logger.debug(f"Selected items in graphics scene: {self.selectedItems()}")
             for item in self.selectedItems():
                 if item is not None:
                     item.setSelected(False)
 
+        self.itemSelected.emit()
         super().mousePressEvent(event)
 
     def mouseReleaseEvent(self, event: QGraphicsSceneMouseEvent) -> None:
         """
-        Handle Qt's mouse's button release event.
+        Handle Qt mouse's button release event.
 
         :param event: Mouse release event
         :type event: ``QGraphicsSceneMouseEvent.py``
@@ -169,16 +171,22 @@ class GraphicsScene(QGraphicsScene):
 
         super().mouseReleaseEvent(event)
 
-    def fitInView(self):
+    def mouseMoveEvent(self, event: QGraphicsSceneMouseEvent) -> None:
+        self.mouseMoved.emit(event.scenePos())
+        super().mouseMoveEvent(event)
+
+    def fitToView(self):
         """
 
         :return:
         """
-        if len(self.scene.nodes) <= 1:
+        if len(self.scene.nodes) + len(self.scene.elements) <= 1:
             return
 
         nodes = self.scene.nodes
         items = [node.graphicsNode for node in nodes]
+        elements = [element.graphicsElement for element in self.scene.elements]
+        items = items + elements
         group = QGraphicsItemGroup()
         for item in items:
             group.addToGroup(item)
@@ -187,20 +195,20 @@ class GraphicsScene(QGraphicsScene):
         maxZoomLevel = self.scene.graphicsView.zoomRange[1]
 
         # Get current scale factor.
-        oldMatrix: QMatrix = self.scene.graphicsView.matrix()
+        oldMatrix: QTransform = self.scene.graphicsView.transform()
         oldScaleFactor = oldMatrix.m11()
         oldZoomLevel = maxZoomLevel + round(log(oldScaleFactor) / log(zoomInFactor))
 
         # Fit in view and estimate new scale factor.
         self.scene.graphicsView.fitInView(group, Qt.KeepAspectRatio)
-        newMatrix = self.scene.graphicsView.matrix()
+        newMatrix = self.scene.graphicsView.transform()
         newScaleFactor = newMatrix.m11()
         newZoomLevel = min(
             maxZoomLevel, maxZoomLevel + floor(log(newScaleFactor) / log(zoomInFactor))
         )
 
         # Restore old scale factor.
-        self.scene.graphicsView.setMatrix(oldMatrix)
+        self.scene.graphicsView.setTransform(oldMatrix)
 
         # Apply new scale factor properly.
         self.scene.graphicsView.zoom = newZoomLevel
