@@ -3,15 +3,15 @@
 Graphics View module containing :class:`~nodedge.graphics_view.GraphicsView`
 and :class:`~nodedge.graphics_view.DragMode` classes.
 """
-
 import logging
 from typing import Callable, List, Optional
 
-from PySide2.QtCore import QEvent, QPointF, Qt, Signal
-from PySide2.QtGui import QDragEnterEvent, QDropEvent, QKeyEvent, QMouseEvent, QPainter
-from PySide2.QtWidgets import QGraphicsItem, QGraphicsView, QWidget
+from PySide6.QtCore import QEvent, QPointF, Qt, Signal
+from PySide6.QtGui import QDragEnterEvent, QDropEvent, QKeyEvent, QMouseEvent, QPainter
+from PySide6.QtWidgets import QGraphicsItem, QGraphicsView, QWidget
 
 from nodedge.edge_dragging import EdgeDragging, EdgeDraggingMode
+from nodedge.elements.element import Element
 from nodedge.graphics_cut_line import CutLine
 from nodedge.graphics_edge import GraphicsEdge
 from nodedge.graphics_scene import GraphicsScene
@@ -24,6 +24,8 @@ EDGE_START_DRAG_THRESHOLD = 40
 
 DEBUG_MMB_SCENE_ITEMS = True
 
+logger = logging.getLogger(__name__)
+
 
 class GraphicsView(QGraphicsView):
     """:class:`~nodedge.graphics_view.GraphicsView` class."""
@@ -41,9 +43,6 @@ class GraphicsView(QGraphicsView):
         """
         super().__init__(graphicsScene, parent)
 
-        self.__logger = logging.getLogger(__name__)
-        self.__logger.setLevel(logging.INFO)
-
         self.graphicsScene: GraphicsScene = graphicsScene
         self.initUI()
 
@@ -90,19 +89,19 @@ class GraphicsView(QGraphicsView):
             or QPainter.TextAntialiasing
             or QPainter.SmoothPixmapTransform
         )
-        self.setViewportUpdateMode(QGraphicsView.FullViewportUpdate)
+        self.setViewportUpdateMode(QGraphicsView.ViewportUpdateMode.FullViewportUpdate)
 
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
 
-        self.setTransformationAnchor(QGraphicsView.AnchorUnderMouse)
-        self.setDragMode(QGraphicsView.RubberBandDrag)
+        self.setTransformationAnchor(QGraphicsView.ViewportAnchor.AnchorUnderMouse)
+        self.setDragMode(QGraphicsView.DragMode.RubberBandDrag)
 
         self.setAcceptDrops(True)
 
     def dragEnterEvent(self, event: QDragEnterEvent) -> None:
         """
-        Handle Qt's mouse's drag enter event.
+        Handle Qt mouse's drag enter event.
 
         Call all the listeners of that event.
 
@@ -114,7 +113,7 @@ class GraphicsView(QGraphicsView):
 
     def dropEvent(self, event: QDropEvent) -> None:
         """
-        Handle Qt's mouse's drop event.
+        Handle Qt mouse's drop event.
 
         Call all the listeners of that event.
 
@@ -142,7 +141,7 @@ class GraphicsView(QGraphicsView):
 
     def mousePressEvent(self, event: QMouseEvent):
         """
-        Dispatch Qt's `mousePressEvent` to corresponding function below.
+        Dispatch Qt `mousePressEvent` to corresponding function below.
         """
         if event.button() == Qt.MiddleButton:
             self.middleMouseButtonPress(event)
@@ -158,7 +157,7 @@ class GraphicsView(QGraphicsView):
 
     def mouseReleaseEvent(self, event: QMouseEvent):
         """
-        Dispatch Qt's mouseReleaseEvent to corresponding function below.
+        Dispatch Qt mouseReleaseEvent to corresponding function below.
         """
         if event.button() == Qt.MiddleButton:
             self.middleMouseButtonRelease(event)
@@ -175,11 +174,11 @@ class GraphicsView(QGraphicsView):
         """
         try:
             item: Optional[QGraphicsItem] = self.getItemAtClick(event)
-            self.__logger.debug(f"Selected object class: {item.__class__.__name__}")
+            logger.debug(f"Selected object class: {item.__class__.__name__}")
 
             self.lastLMBClickScenePos = self.mapToScene(event.pos())
 
-            self.__logger.debug("LMB " + GraphicsView.debugModifiers(event) + f"{item}")
+            logger.debug("LMB " + GraphicsView.debugModifiers(event) + f"{item}")
 
             if event.modifiers() & Qt.ShiftModifier:
                 event.ignore()
@@ -243,9 +242,9 @@ class GraphicsView(QGraphicsView):
                 selectedItems = self.graphicsScene.selectedItems()
                 if selectedItems != self.graphicsScene.scene.lastSelectedItems:
                     if not selectedItems:
-                        self.graphicsScene.itemsDeselected.emit()  # type: ignore
+                        self.graphicsScene.itemsDeselected.emit()
                     else:
-                        self.graphicsScene.itemSelected.emit()  # type: ignore
+                        self.graphicsScene.itemSelected.emit()
                 return
         except Exception as e:
             dumpException(e)
@@ -261,27 +260,23 @@ class GraphicsView(QGraphicsView):
 
         if DEBUG_MMB_SCENE_ITEMS:
             if item is None:
-                if event.modifiers() & Qt.SHIFT:
+                if event.modifiers() & Qt.ShiftModifier:
                     lastSelectedItems = self.graphicsScene.scene.lastSelectedItems
-                    self.__logger.info(
+                    logger.info(
                         f"\n||||Last selected items: {lastSelectedItems}",
                     )
-                    return
-                self.__logger.info(self)
-                return
+                logger.info(self)
             elif isinstance(item, GraphicsSocket):
-                self.__logger.info(
+                logger.info(
                     f"\n||||{item.socket} connected to \n||||{item.socket.edges}"
                 )
-                return
             elif isinstance(item, GraphicsEdge):
                 log = f"\n||||{item.edge} connects"
                 log += (
                     f"\n||||{item.edge.sourceSocket.node} \n||||"
                     f"{item.edge.targetSocket.node}"
                 )
-                self.__logger.info(log)
-                return
+                logger.info(log)
 
         # Faking event to enable mouse dragging the scene
         release_event = QMouseEvent(
@@ -293,7 +288,7 @@ class GraphicsView(QGraphicsView):
             event.modifiers(),
         )
         super().mouseReleaseEvent(release_event)
-        self.setDragMode(QGraphicsView.ScrollHandDrag)
+        self.setDragMode(QGraphicsView.DragMode.ScrollHandDrag)
         fake_event = QMouseEvent(
             event.type(),
             event.localPos(),
@@ -317,7 +312,7 @@ class GraphicsView(QGraphicsView):
             event.modifiers(),
         )
         super().mouseReleaseEvent(fake_event)
-        self.setDragMode(QGraphicsView.RubberBandDrag)
+        self.setDragMode(QGraphicsView.DragMode.RubberBandDrag)
 
     def rightMouseButtonPress(self, event: QMouseEvent):
         """
@@ -333,9 +328,9 @@ class GraphicsView(QGraphicsView):
 
     def mouseMoveEvent(self, event: QMouseEvent) -> None:
         """
-        Overridden Qt's ``mouseMoveEvent`` handling Scene/View logic
+        Overridden Qt ``mouseMoveEvent`` handling Scene/View logic
 
-        :param event: Qt's mouse event
+        :param event: Qt mouse event
         :type event: ``QMouseEvent.py``
         """
         eventScenePos = self.mapToScene(event.pos())
@@ -348,15 +343,13 @@ class GraphicsView(QGraphicsView):
                 self.edgeDragging.dragEdge.graphicsEdge.targetPos = eventScenePos
                 self.edgeDragging.dragEdge.graphicsEdge.update()
             else:
-                self.__logger.debug("Dragging edge does not exist.")
+                logger.debug("Dragging edge does not exist.")
 
         self.cutLine.update(event)
 
         self.lastSceneMousePos = eventScenePos
         # noinspection PyUnresolvedReferences
-        self.scenePosChanged.emit(  # type: ignore
-            int(eventScenePos.x()), int(eventScenePos.y())
-        )
+        self.scenePosChanged.emit(int(eventScenePos.x()), int(eventScenePos.y()))
 
         super().mouseMoveEvent(event)
 
@@ -364,7 +357,7 @@ class GraphicsView(QGraphicsView):
         """
         Handle key shortcuts, for example to display the scene's history in the console.
 
-        :param event: Qt's Key event
+        :param event: QtKey event
         :type event: ``QKeyEvent.py``
         """
 
@@ -382,21 +375,42 @@ class GraphicsView(QGraphicsView):
         # self.graphicsScene.scene.history.undo() elif event.key() == Qt.Key_Z and
         # event.modifiers() & Qt.ControlModifier and event.modifiers() &
         # Qt.ShiftModifier: self.graphicsScene.scene.history.redo()
+        dPos = [0, 0]
+        if event.modifiers() & Qt.AltModifier:
+            if event.key() == Qt.Key_Left:
+                dPos[0] = -10
+            elif event.key() == Qt.Key_Right:
+                dPos[0] = 10
+            elif event.key() == Qt.Key_Up:
+                dPos[1] = -10
+            elif event.key() == Qt.Key_Down:
+                dPos[1] = 10
+
+            for item in self.scene().selectedItems():
+                if hasattr(item, "node"):
+                    item.node.pos = item.pos() + QPointF(*dPos)
+                    item.node.updateConnectedEdges()
+
+            if dPos != [0, 0]:
+                event.accept()
+                return
+
         if event.key() == Qt.Key_H:
-            self.__logger.info(f"{self.graphicsScene.scene.history}")
+            logger.info(f"{self.graphicsScene.scene.history}")
+            super().keyPressEvent(event)
 
         else:
             super().keyPressEvent(event)
 
     def wheelEvent(self, event):
         """
-        Overridden Qt's ``wheelEvent``.
+        Overridden Qt ``wheelEvent``.
         This handles zooming.
         """
         zoomIn = event.angleDelta().y() > 0
         self.updateZoom(zoomIn)
-        self.__logger.debug(
-            f"Scale: {self.matrix().m11()}, "
+        logger.debug(
+            f"Scale: {self.transform().m11()}, "
             f"Zoom factor: {self.zoomInFactor}, "
             f"Zoom level: {self.zoom}"
         )
@@ -433,6 +447,9 @@ class GraphicsView(QGraphicsView):
             elif hasattr(item, "node"):
                 node: Node = item.node
                 node.remove()
+            elif hasattr(item, "element"):
+                element: Element = item.element
+                element.remove()
 
         self.graphicsScene.scene.history.store("Delete selected objects.")
 
@@ -440,7 +457,7 @@ class GraphicsView(QGraphicsView):
         """
         Return the object on which the user clicked/released the mouse button.
 
-        :param event: Qt's mouse or key event
+        :param event: Qt mouse or key event
         :type event: ``QMouseEvent.py``
         :return: Graphical item present at the clicked/released position.
         :rtype: ``QGraphicsItem`` | ``None``
@@ -454,7 +471,7 @@ class GraphicsView(QGraphicsView):
         This is used for detection if the release is too far after the user clicked
         on a :class:`~nodedge.socket.Socket`
 
-        :param event: Qt's mouse event
+        :param event: Qt mouse event
         :type event: ``QMouseEvent.py``
         :return: ``True`` if we released too far from where we clicked before, ``False``
             otherwise.
@@ -464,10 +481,10 @@ class GraphicsView(QGraphicsView):
             return False
         newLMBClickPos: QPointF = self.mapToScene(event.pos())
         distScene = newLMBClickPos - self.lastLMBClickScenePos
-        edgeStartDragThresholdSquared = EDGE_START_DRAG_THRESHOLD ** 2
+        edgeStartDragThresholdSquared = EDGE_START_DRAG_THRESHOLD**2
         distSceneSquared = distScene.x() * distScene.x() + distScene.y() * distScene.y()
         if distSceneSquared < edgeStartDragThresholdSquared:
-            self.__logger.debug(
+            logger.debug(
                 f"Squared distance between new and last LMB click: "
                 f"{distSceneSquared} < {edgeStartDragThresholdSquared}"
             )
