@@ -1,21 +1,21 @@
 # -*- coding: utf-8 -*-
 """
-Editor widget module containing :class:`~nodedge.editor_widget.EditorWidget` class.
+Mdi widget module containing :class:`~nodedge.mdi_widget.MdiWidget` class.
 """
 import logging
 from typing import Callable, List, Optional
 
-from PySide2.QtCore import QDataStream, QIODevice, Qt
-from PySide2.QtGui import (
+from PySide6.QtCore import QDataStream, QIODevice, Qt
+from PySide6.QtGui import (
+    QAction,
     QCloseEvent,
     QContextMenuEvent,
     QDragEnterEvent,
     QDropEvent,
-    QIcon,
     QMouseEvent,
     QPixmap,
 )
-from PySide2.QtWidgets import QAction, QGraphicsProxyWidget, QMenu
+from PySide6.QtWidgets import QGraphicsProxyWidget, QGraphicsTextItem, QMenu
 
 from nodedge.blocks.block import Block
 from nodedge.blocks.block_config import BLOCKS, getClassFromOperationCode
@@ -68,15 +68,20 @@ class MdiWidget(EditorWidget):
         :class:`~nodedge.node_list_widget.NodeListWidget`.
         """
         self.nodeActions = {}
+        self.libraryMenus = {}
 
         keys = list(BLOCKS.keys())
         keys.sort()
 
         for key in keys:
             node: Block = BLOCKS[key]
-            self.nodeActions[node.operationCode] = QAction(
-                QIcon(node.icon), node.operationTitle
+            self.nodeActions[node.operationCode] = QAction(  # QIcon(node.icon),
+                node.operationTitle
             )
+            if node.library not in self.libraryMenus.keys():
+                menu = QMenu(node.library.capitalize())
+                self.libraryMenus[node.library] = menu
+
             self.nodeActions[node.operationCode].setData(node.operationCode)
 
     def initNodesContextMenu(self):
@@ -88,8 +93,17 @@ class MdiWidget(EditorWidget):
         contextMenu = QMenu(self)
         keys = list(BLOCKS.keys())
         keys.sort()
+        menus = {}
         for key in keys:
-            contextMenu.addAction(self.nodeActions[key])
+            node = getClassFromOperationCode(key)
+            library = node.library
+            if library not in menus.keys():
+                contextMenu.addMenu(self.libraryMenus[library])
+                menus[library] = self.libraryMenus[library]
+            else:
+                menu = menus[library]
+            menus[library].addAction(self.nodeActions[node.operationCode])
+            # contextMenu.addAction(self.nodeActions[key])
 
         return contextMenu
 
@@ -121,11 +135,11 @@ class MdiWidget(EditorWidget):
 
     def closeEvent(self, event: QCloseEvent) -> None:
         """
-        Handle Qt's close event.
+        Handle Qt close event.
 
         Make sure changes have been saved before closing the widget.
 
-        :param event: Qt's close event, the user may have clicked on the close button,
+        :param event: Qt close event, the user may have clicked on the close button,
             or pressed CTRL+W
         :type event: ``QCloseEvent.py``
         """
@@ -141,7 +155,7 @@ class MdiWidget(EditorWidget):
         :class:`~nodedge.node_list_widget.NodeListWidget`, its logo is displayed
         above the scene, near the location of the mouse.
 
-        :param event: the Qt's drag event event, containing the mime data of the node
+        :param event: the Qt drag event event, containing the mime data of the node
             being dragged
         :return: QDragEnterEvent
         """
@@ -161,7 +175,7 @@ class MdiWidget(EditorWidget):
         When the node is dropped, an instance of it is created near at the mouse
         location, displayed by its :class:`~nodedge.graphics_node.GraphicsNode`.
 
-        :param event: the Qt's drop event, containing the mime data of the node being
+        :param event: the Qt drop event, containing the mime data of the node being
             dropped.
         :type event: QDropEvent.py
         """
@@ -202,10 +216,10 @@ class MdiWidget(EditorWidget):
 
     def contextMenuEvent(self, event: QContextMenuEvent):
         """
-        Handle Qt's context menu event.
+        Handle Qt context menu event.
 
 
-        :param event: the Qt's context menu event, happening when the user right
+        :param event: the Qt context menu event, happening when the user right
             clicks on the :class:`~nodedge.graphics_scene.GraphicsScene`
         :type event: ``QContextMenuEvent.py``
         """
@@ -221,6 +235,8 @@ class MdiWidget(EditorWidget):
             elif hasattr(item, "edge"):
                 self.handleEdgeContextMenu(event)
             # elif item is None:
+            elif isinstance(item, QGraphicsTextItem):
+                self.__contextLogger.debug("Right click on a comment.")
             else:
                 self.handleNewNodeContextMenu(event)
 
@@ -230,9 +246,9 @@ class MdiWidget(EditorWidget):
 
     def handleNodeContextMenu(self, event: QContextMenuEvent):
         """
-        Handle Qt's context menu event when the user has clicked on a node.
+        Handle Qt context menu event when the user has clicked on a node.
 
-        :param event: Qt's context menu event, happening when the users
+        :param event: Qt context menu event, happening when the users
         :return: ``QContextMenuEvent``
         """
         contextMenu = QMenu()
@@ -241,7 +257,7 @@ class MdiWidget(EditorWidget):
         markInvalidAct = contextMenu.addAction("Mark invalid")
         unmarkAct = contextMenu.addAction("Unmark invalid")
         evalAct = contextMenu.addAction("Eval")
-        action = QMenu.exec_(self.mapToGlobal(event.pos()))
+        action = QMenu.exec_(self.mapToGlobal(event.pos()))  # type: ignore
 
         selected = None
         item = self.scene.itemAt(event.pos())
@@ -297,7 +313,7 @@ class MdiWidget(EditorWidget):
         Show all available nodes available in a list context menu, so that the users
         can quickly create a new one.
 
-        :param event: the Qt's context menu event, happening when the user right
+        :param event: the Qt context menu event, happening when the user right
             clicks on the :class:`~nodedge.graphics_scene.GraphicsScene`
         :type event: ``QContextMenuEvent.py``
         """
@@ -337,16 +353,17 @@ class MdiWidget(EditorWidget):
 
     def handleEdgeContextMenu(self, event):
         """
-        Handle Qt's context menu when the user has right clicked on an
+        Handle Qt context menu when the user has right clicked on an
         :class:`~nodedge.graphics_edge.GraphicsEdge`
 
-        :param event: the Qt's context menu event, happening when the user right clicks
+        :param event: the Qt context menu event, happening when the user right clicks
             on the :class:`~nodedge.graphics_scene.GraphicsScene`
         :type event: ``QContextMenuEvent``
         """
         contextMenu = QMenu()
-        bezierAct = contextMenu.addAction("Bezier Edge")
-        directAct = contextMenu.addAction("Direct Edge")
+        bezierAct = contextMenu.addAction("Bezier edge")
+        directAct = contextMenu.addAction("Direct edge")
+        circuitAct = contextMenu.addAction("Circuit edge")
         action = contextMenu.exec_(self.mapToGlobal(event.pos()))
 
         selected = None
@@ -355,16 +372,19 @@ class MdiWidget(EditorWidget):
         if hasattr(item, "edge"):
             selected = item.edge
 
-        if selected and action == bezierAct:
-            selected.edgeType = EdgeType.BEZIER
-        if selected and action == directAct:
-            selected.edgeType = EdgeType.STRAIGHT
+        if selected:
+            if action == bezierAct:
+                selected.edgeType = EdgeType.BEZIER
+            elif action == directAct:
+                selected.edgeType = EdgeType.STRAIGHT
+            elif action == circuitAct:
+                selected.edgeType = EdgeType.CIRCUIT
 
     def mouseReleaseEvent(self, event: QMouseEvent):
         """
-        Handle Qt's mouse release event.
+        Handle Qt mouse release event.
 
-        :param event: Qt's mouse release event
+        :param event: Qt mouse release event
         :return: ``QMouseEvent``
         """
         super().mouseReleaseEvent(event)
