@@ -5,11 +5,9 @@ import logging
 import os
 from typing import Any, Callable, List, Optional, cast
 
-from pyqtconsole.console import PythonConsole
-from PySide2.QtCore import QSignalMapper, QSize, Qt, QTimer, Slot
-from PySide2.QtGui import QCloseEvent, QIcon, QKeySequence, QMouseEvent
-from PySide2.QtWidgets import (
-    QAction,
+from PySide6.QtCore import QPointF, QSignalMapper, QSize, Qt, QTimer, Slot
+from PySide6.QtGui import QAction, QCloseEvent, QIcon, QKeySequence, QMouseEvent
+from PySide6.QtWidgets import (
     QDialog,
     QDockWidget,
     QFileDialog,
@@ -23,12 +21,14 @@ from PySide2.QtWidgets import (
 from nodedge.editor_widget import EditorWidget
 from nodedge.editor_window import EditorWindow
 from nodedge.history_list_widget import HistoryListWidget
+from nodedge.home_menu import HomeMenu, MenuBar
 from nodedge.mdi_area import MdiArea
 from nodedge.mdi_widget import MdiWidget
 from nodedge.node_tree_widget import NodeTreeWidget
 from nodedge.scene_item_detail_widget import SceneItemDetailWidget
 from nodedge.scene_items_table_widget import SceneItemsTableWidget
-from nodedge.utils import loadStyleSheets
+
+logger = logging.getLogger(__name__)
 
 
 class MdiWindow(EditorWindow):
@@ -43,8 +43,6 @@ class MdiWindow(EditorWindow):
         self.__logger.setLevel(logging.INFO)
         self.currentEditorWidgetChangedListeners: List[Callable] = []
 
-        self.stylesheetLastModified: float = 0.0
-
         super(MdiWindow, self).__init__()
 
     @property
@@ -59,9 +57,11 @@ class MdiWindow(EditorWindow):
 
         :type: :class:`~nodedge.editor_widget.EditorWidget`
         """
+        if not self.mdiArea.subWindowList():
+            self.lastActiveEditorWidget = None
         activeSubWindow = self.mdiArea.activeSubWindow()
         if (
-            activeSubWindow is not None  # type: ignore
+            activeSubWindow is not None
             and activeSubWindow.widget() is not None
             and isinstance(activeSubWindow.widget(), EditorWidget)
         ):
@@ -78,42 +78,36 @@ class MdiWindow(EditorWindow):
         self.companyName = "Nodedge"
         self.productName = "Nodedge"
         self.icon = QIcon(
-            os.path.join(os.path.dirname(__file__), "resources/nodedge_logo.png")
+            os.path.join(os.path.dirname(__file__), "../resources/nodedge_logo.png")
         )
         self.setWindowIcon(self.icon)
         self.setMinimumSize(QSize(880, 600))
 
-        self.styleSheetFilename = os.path.join(
-            os.path.dirname(__file__), "qss/nodedge_style.qss"
-        )
-        loadStyleSheets(
-            # os.path.join(os.path.dirname(__file__), "qss/calculator-dark.qss"),
-            self.styleSheetFilename
-        )
+        # self.styleSheetFilename = os.path.join(
+        #     os.path.dirname(__file__), "../resources/qss/nodedge_style.qss"
+        # )
+        # loadStyleSheets(
+        #     # os.path.join(os.path.dirname(__file__), "qss/calculator-dark.qss"),
+        #     self.styleSheetFilename
+        # )
 
         self.setMouseTracking(True)
 
-        self.timer = QTimer()
-        self.timer.setTimerType(Qt.PreciseTimer)
-        self.timer.setInterval(500)
-        self.timer.timeout.connect(self.checkStylesheet)
-        self.timer.start()
-
         self.mdiArea = MdiArea()
         self.setCentralWidget(self.mdiArea)
 
         self.addCurrentEditorWidgetChangedListener(self.updateMenus)
 
-        self.mdiArea.subWindowActivated.connect(self.onSubWindowActivated)
+        self.mdiArea.subWindowActivated.connect(self.onSubWindowActivated)  # type: ignore
 
         self.windowMapper = QSignalMapper(self)
-        self.windowMapper.mapped[QWidget].connect(self.setActiveSubWindow)
+        self.windowMapper.mappedObject.connect(self.setActiveSubWindow)  # type: ignore
 
         self.createSceneItemDetailDock()
         self.createNodesDock()
         self.createHistoryDock()
         self.createSceneItemsDock()
-        self.createPythonConsole()
+        # self.createPythonConsole()
 
         self.createActions()
         self.createMenus()
@@ -155,6 +149,13 @@ class MdiWindow(EditorWindow):
             "&Cascade", self.mdiArea.cascadeSubWindows, "Cascade the windows"
         )
 
+        self.hideToolbarAct = self.createAction(
+            "Hide toolbars",
+            self.hideToolBars,
+            "Hide toolbars",
+            QKeySequence("Ctrl+T"),
+        )
+
         self.nextAct = self.createAction(
             "Ne&xt",
             self.mdiArea.activateNextSubWindow,
@@ -191,7 +192,8 @@ class MdiWindow(EditorWindow):
             "&Debug",
             self.onDebugSwitched,
             "Enable/Disable the debug mode",
-            QKeySequence("ctrl+alt+shift+d"),
+            QKeySequence("ctrl+shift+d"),
+            checkable=True,
         )
 
         self.showDialogActionsAct = self.createAction(
@@ -201,26 +203,57 @@ class MdiWindow(EditorWindow):
             QKeySequence("ctrl+shift+a"),
         )
 
+        self.addCommentElementAct = self.createAction(
+            "Add comment",
+            self.addCommentElement,
+            "Add comment element in current scene",
+            QKeySequence("Ctrl+Alt+C"),
+        )
+
+    def evaluateAllNodes(self):
+        if self.currentEditorWidget is None:
+            return
+        for n in self.currentEditorWidget.scene.nodes:
+            n.isDirty = True
+        for n in self.currentEditorWidget.scene.nodes:
+            n.eval()
+
     # noinspection PyAttributeOutsideInit
     def createToolBars(self) -> None:
         """
         Create the `File` and `Edit` toolbar containing few of their menu actions.
         """
+        self.toolBars = []
         self.fileToolBar: QToolBar = self.addToolBar("File")
         self.fileToolBar.setMovable(False)
         self.fileToolBar.addAction(self.newAct)
         self.fileToolBar.addAction(self.openAct)
         self.fileToolBar.addAction(self.saveAct)
         self.fileToolBar.addSeparator()
+        self.toolBars.append(self.fileToolBar)
 
         self.editToolBar = self.addToolBar("Edit")
         self.editToolBar.setMovable(False)
         self.editToolBar.addAction(self.cutAct)
         self.editToolBar.addAction(self.copyAct)
         self.editToolBar.addAction(self.pasteAct)
+        self.editToolBar.addAction(self.addCommentElementAct)
+        self.editToolBar.addSeparator()
+        self.toolBars.append(self.editToolBar)
 
-        self.coderToolbar = self.addToolBar("Coder")
-        self.coderToolbar.addAction(self.generateCodeAct)
+        self.coderToolBar = self.addToolBar("Coder")
+        # self.coderToolBar.setMovable(False)
+        self.coderToolBar.addAction(self.generateCodeAct)
+        self.coderToolBar.addAction(self.configureSolverAct)
+        self.toolBars.append(self.coderToolBar)
+
+    def hideToolBars(self):
+        if self.toolBars[0].isVisible():
+            for toolBar in self.toolBars:
+                toolBar.hide()
+        else:
+            for toolBar in self.toolBars:
+                toolBar.show()
 
     def createMenus(self) -> None:
         """
@@ -229,30 +262,31 @@ class MdiWindow(EditorWindow):
         `Window` menu allows to navigate between the sub-windows.
         `Help` menu allows to display know more about Nodedge.
         """
-        self.createHomeMenu()
+        self.menubar = MenuBar(self)
+        self.setMenuBar(self.menubar)
+        self.homeMenu = self.menubar.homeMenu
+        self.homeMenu.aboutToShow.connect(self.closeHomeMenu)
+
+        # self.createHomeMenu()
 
         super().createMenus()
-
         self.createWindowMenu()
         self.createHelpMenu()
 
         # noinspection PyUnresolvedReferences
-        self.editMenu.aboutToShow.connect(self.updateEditMenu)
+        self.editMenu.aboutToShow.connect(self.updateEditMenu)  # type: ignore
 
     # noinspection PyAttributeOutsideInit
     def createHomeMenu(self):
-        self.homeMenu: QMenu = self.menuBar().addMenu(
-            QIcon("../../nodedge/resources/iconsModified/home_page_100.png"), "&Home"
-        )
-        self.homeMenu.aboutToShow.connect(self.openHome)
+        # QIcon("../resources/white_icons/home_page.png")
+        self.homeMenu = HomeMenu(self)
+        self.menuBar().addMenu(self.homeMenu)
 
-    def openHome(self):
-        msg = QMessageBox()
-        msg.setIcon(QMessageBox.Information)
-        msg.setInformativeText("It is not yet implemented.")
-        msg.setWindowTitle("Home page")
-        msg.setStandardButtons(QMessageBox.Ok)
-        msg.exec_()
+        # self.homeMenu.aboutToShow.connect(self.closeHomeMenu)
+
+    def closeHomeMenu(self):
+        timer = QTimer(self)
+        timer.singleShot(1, self.homeMenu.hide)
 
     # noinspection PyAttributeOutsideInit
     def createHelpMenu(self) -> None:
@@ -261,6 +295,8 @@ class MdiWindow(EditorWindow):
         """
         self.helpMenu: QMenu = self.menuBar().addMenu("&Help")
         self.helpMenu.addAction(self.aboutAct)
+        self.helpMenu.addAction(self.debugAct)
+        self.helpMenu.addAction(self.showDialogActionsAct)
 
     # noinspection PyAttributeOutsideInit
     def createWindowMenu(self) -> None:
@@ -269,7 +305,7 @@ class MdiWindow(EditorWindow):
         """
         self.windowMenu = self.menuBar().addMenu("&Window")
         # noinspection PyUnresolvedReferences
-        self.windowMenu.aboutToShow.connect(self.updateWindowMenu)
+        self.windowMenu.aboutToShow.connect(self.updateWindowMenu)  # type: ignore
 
     def updateMenus(self) -> None:
         """
@@ -339,7 +375,7 @@ class MdiWindow(EditorWindow):
             action.setCheckable(True)
             action.setChecked(editorWidget is self.currentEditorWidget)
             # noinspection PyUnresolvedReferences
-            action.triggered.connect(self.windowMapper.map)
+            action.triggered.connect(self.windowMapper.map)  # type: ignore
             self.windowMapper.setMapping(action, window)
 
     def updateEditMenu(self) -> None:
@@ -371,10 +407,11 @@ class MdiWindow(EditorWindow):
         :class:`~nodedge.editor_widget.EditorWidget`
         """
         editor: MdiWidget = childWidget if childWidget is not None else MdiWidget()
-        editor.scene.coder.notConnectedSocket.connect(  # type: ignore
+        editor.scene.coder.notConnectedSocket.connect(
             self.onSceneCoderOutputSocketDisconnect
         )
         subWindow = self.mdiArea.addSubWindow(editor)
+        self.mdiArea.setActiveSubWindow(subWindow)
 
         icon = QIcon(".")
         subWindow.setWindowIcon(icon)
@@ -383,6 +420,7 @@ class MdiWindow(EditorWindow):
         editor.scene.history.addHistoryModifiedListener(
             self.sceneItemsTableWidget.update
         )
+        editor.scene.addItemsDeselectedListener(self.sceneItemDetailsWidget.update)
         editor.scene.addItemSelectedListener(self.sceneItemDetailsWidget.update)
         editor.addCloseEventListener(self.onSubWindowClosed)
 
@@ -402,6 +440,8 @@ class MdiWindow(EditorWindow):
             return
 
         self.mdiArea.setActiveSubWindow(subWindowToBeDeleted)
+        self.sceneItemsTableWidget.scene = None
+        self.sceneItemsTableWidget.clearContents()
 
         if self.maybeSave():
             event.accept()
@@ -419,7 +459,7 @@ class MdiWindow(EditorWindow):
         for window in self.mdiArea.subWindowList():
             editorWidget: EditorWidget = cast(EditorWidget, window.widget())
             if editorWidget.filename == filename:
-                return cast(QMdiSubWindow, window)
+                return window
         return None
 
     def setActiveSubWindow(self, window: QMdiSubWindow) -> None:
@@ -441,7 +481,7 @@ class MdiWindow(EditorWindow):
         """
         self.sceneItemDetailsWidget = SceneItemDetailWidget(self)
 
-        self.sceneItemDetailsDock = QDockWidget("Item details")
+        self.sceneItemDetailsDock = QDockWidget("Node details")
         self.sceneItemDetailsDock.setWidget(self.sceneItemDetailsWidget)
         self.sceneItemDetailsDock.setFloating(False)
 
@@ -453,11 +493,9 @@ class MdiWindow(EditorWindow):
         Create Nodes dock.
         """
         self.nodesTreeWidget = NodeTreeWidget()
-        self.nodesTreeWidget.itemsPressed.connect(  # type: ignore
-            self.showItemsInStatusBar
-        )
+        self.nodesTreeWidget.itemsPressed.connect(self.showItemsInStatusBar)
 
-        self.nodesDock = QDockWidget("Nodes")
+        self.nodesDock = QDockWidget("Node libraries")
         self.nodesDock.setWidget(self.nodesTreeWidget)
         self.nodesDock.setFloating(False)
 
@@ -469,9 +507,7 @@ class MdiWindow(EditorWindow):
         Create history dock.
         """
         self.historyListWidget = HistoryListWidget(self)
-        self.historyListWidget.itemsPressed.connect(  # type: ignore
-            self.showItemsInStatusBar
-        )
+        self.historyListWidget.itemsPressed.connect(self.showItemsInStatusBar)
         self.addCurrentEditorWidgetChangedListener(self.historyListWidget.update)
 
         self.historyDock = QDockWidget("History")
@@ -486,9 +522,7 @@ class MdiWindow(EditorWindow):
         Create scene items dock.
         """
         self.sceneItemsTableWidget = SceneItemsTableWidget(self)
-        self.sceneItemsTableWidget.itemsPressed.connect(  # type: ignore
-            self.showItemsInStatusBar
-        )
+        self.sceneItemsTableWidget.itemsPressed.connect(self.showItemsInStatusBar)
         self.addCurrentEditorWidgetChangedListener(self.sceneItemsTableWidget.update)
 
         self.sceneItemsDock = QDockWidget("Scene items")
@@ -496,6 +530,7 @@ class MdiWindow(EditorWindow):
         self.sceneItemsDock.setFloating(False)
 
         self.addDockWidget(Qt.LeftDockWidgetArea, self.sceneItemsDock)
+        self.sceneItemsDock.hide()
 
     # noinspection PyAttributeOutsideInit
     def createPythonConsole(self) -> None:
@@ -503,18 +538,20 @@ class MdiWindow(EditorWindow):
         Create a python console embedded in a dock.
         :return: ``None``
         """
-        self.pythonConsoleWidget = PythonConsole(formats=self.styler.consoleStyle)
-        self.pythonConsoleWidget.eval_in_thread()
+        # self.pythonConsoleWidget = PythonConsole(formats=self.styler.consoleStyle)
+        # self.pythonConsoleWidget.eval_in_thread()
 
-        self.pythonConsoleDock = QDockWidget("Python console")
-        self.pythonConsoleDock.setWidget(self.pythonConsoleWidget)
-        self.pythonConsoleDock.setFloating(False)
+        # self.pythonConsoleDock = QDockWidget("Python console")
+        # self.pythonConsoleDock.setWidget(self.pythonConsoleWidget)
+        # self.pythonConsoleDock.setFloating(False)
 
-        self.addDockWidget(Qt.LeftDockWidgetArea, self.pythonConsoleDock)
+        # self.addDockWidget(Qt.LeftDockWidgetArea, self.pythonConsoleDock)
+
+        pass
 
     def closeEvent(self, event: QCloseEvent) -> None:
         """
-        Qt's close event handle.
+        Qt close event handle.
 
         :param event: close event
         :type event: ``QCloseEvent.py``
@@ -525,7 +562,7 @@ class MdiWindow(EditorWindow):
             event.ignore()
         else:
             self.writeSettings()
-            self.pythonConsoleWidget.close()
+            # self.pythonConsoleWidget.close()
             event.accept()
 
     def newFile(self) -> QMdiSubWindow:
@@ -553,12 +590,14 @@ class MdiWindow(EditorWindow):
         :return: ``None``
         """
         if isinstance(filenames, bool) or filenames is None:
-            filenames, _ = QFileDialog.getOpenFileNames(
+            filenames, ok = QFileDialog.getOpenFileNames(
                 parent=self,
                 caption="Open graph from file",
                 dir=EditorWindow.getFileDialogDirectory(),
                 filter=EditorWindow.getFileDialogFilter(),
             )
+            if not ok:
+                return
         else:
             # If only one file is given as input,
             # convert the string in list to let the next for loop work properly.
@@ -568,6 +607,22 @@ class MdiWindow(EditorWindow):
         for filename in filenames:
             self.__logger.debug(f"Loading {filename}")
             if filename:
+                if not os.path.exists(filename):
+                    ok = QMessageBox.warning(
+                        self,
+                        "File not found",
+                        f"File {filename} does not exist. \n"
+                        "Do you want to open a new file?",
+                        QMessageBox.StandardButton.Ok
+                        | QMessageBox.StandardButton.Cancel,
+                    )
+                    self.removeFromRecentFiles(filename)
+                    if ok == QMessageBox.StandardButton.Ok:
+                        self.newFile()
+                    else:
+                        logger.warning(f"File {filename} not found.")
+                        continue
+
                 existingSubWindow = self.findMdiSubWindow(filename)
                 if existingSubWindow:
                     self.__logger.debug("Existing sub window")
@@ -585,6 +640,12 @@ class MdiWindow(EditorWindow):
                     else:
                         self.__logger.debug("Loading fail")
                         editor.close()
+            else:
+                editor = MdiWidget()
+                editor.newFile()
+                subWindow = self._createMdiSubWindow(editor)
+                subWindow.show()
+                self.sceneItemsTableWidget.update()
 
     def about(self) -> None:
         """
@@ -602,6 +663,11 @@ class MdiWindow(EditorWindow):
             "Isaac Asimov.",
         )
 
+    def addCommentElement(self):
+        if self.currentEditorWidget is not None:
+            scene = self.currentEditorWidget.scene
+            scene.addElement()
+
     def onNodesToolbarTriggered(self) -> None:
         """
         Slot called when the nodes toolbar has been triggered.
@@ -637,25 +703,13 @@ class MdiWindow(EditorWindow):
             self.historyListWidget.history = self.currentEditorWidget.scene.history
             self.sceneItemsTableWidget.scene = self.currentEditorWidget.scene
             graphicsScene = self.currentEditorWidget.scene.graphicsScene
-            graphicsScene.itemsPressed.connect(  # type: ignore
-                self.showItemsInStatusBar
-            )
+            graphicsScene.itemsPressed.connect(self.showItemsInStatusBar)
+            graphicsScene.mouseMoved.connect(self.updateStatusBar)
 
-    def checkStylesheet(self) -> None:
-        """
-        Helper function which checks if the stylesheet exists and has changed.
-        """
-        try:
-            modTime = os.path.getmtime(self.styleSheetFilename)
-        except FileNotFoundError:
-            self.__logger.warning("Stylesheet was not found")
-            return
+    def updateStatusBar(self, point: QPointF):
+        self.statusMousePos.setText(f"{point.x()}, {point.y()}")
 
-        if modTime != self.stylesheetLastModified:
-            self.stylesheetLastModified = modTime
-            loadStyleSheets(self.styleSheetFilename)
-
-    @Slot(list)  # type: ignore
+    @Slot(list)
     def showItemsInStatusBar(self, items: List[str]):
         """
         Slot triggered when an item has been selected.
@@ -668,9 +722,19 @@ class MdiWindow(EditorWindow):
 
     def onDebugSwitched(self):
         """Event called when the debug action is triggered."""
-        pass
+        self.debugMode = not self.debugMode
+        if self.debugMode:
+            self.__logger.debug("Debug mode activated")
+            self.statusBar().showMessage("Debug mode activated")
+            self.sceneItemsDock.show()
+            self.debugAct.setChecked(True)
+        else:
+            self.__logger.debug("Debug mode deactivated")
+            self.statusBar().showMessage("Debug mode deactivated")
+            self.sceneItemsDock.hide()
+            self.debugAct.setChecked(False)
 
-    @Slot()  # type: ignore
+    @Slot()
     def onShowDialogActions(self):
         self.__logger.info("")
         dialog = QDialog()
@@ -682,7 +746,7 @@ class MdiWindow(EditorWindow):
 
         super().mouseMoveEvent(event)
 
-    @Slot()  # type: ignore
+    @Slot()
     def onSceneCoderOutputSocketDisconnect(self) -> None:
         """
         Callback to deal with :class:`~nodedge.scene_coder.SceneCoder` warning.
