@@ -6,20 +6,23 @@ Node module containing :class:`~nodedge.node.Node` class.
 
 import logging
 from collections import OrderedDict
-from typing import Callable, Collection, List, Optional, Tuple, TypeVar, cast
+from typing import Callable, Collection, List, Optional, cast
 
-from PySide2.QtCore import QPoint, QPointF
-from PySide2.QtWidgets import QGraphicsSceneMouseEvent
+from PySide6.QtCore import QPointF
+from PySide6.QtWidgets import QGraphicsSceneMouseEvent
 
+from nodedge import utils
 from nodedge.connector import Socket, SocketLocation
 from nodedge.edge import Edge
 from nodedge.graphics_node import GraphicsNode
 from nodedge.graphics_node_content import GraphicsNodeContent
 from nodedge.serializable import Serializable
 from nodedge.socket_type import SocketType
+
+# from nodedge.types import Pos
 from nodedge.utils import dumpException
 
-Pos = TypeVar("Pos", List, Tuple, QPoint, QPointF)
+logger = logging.getLogger(__name__)
 
 
 class NodesAndSockets:
@@ -207,15 +210,9 @@ class Node(Serializable):
         otherNodes = self.scene.nodes.copy()
         if self in self.scene.nodes:
             otherNodes.remove(self)
-        alreadyExistingNames = [node.title for node in otherNodes]
+        alreadyExistingTitles = [node.title for node in otherNodes]
 
-        while newTitle in alreadyExistingNames:
-            if newTitle[-1].isnumeric():
-                newLastCharacter = str(int(newTitle[-1]) + 1)
-                newTitle = newTitle[:-1]
-                newTitle += newLastCharacter
-            else:
-                newTitle += "1"
+        newTitle = utils.setNewTitle(newTitle, alreadyExistingTitles)
 
         self._title = newTitle
         self.graphicsNode.title = newTitle
@@ -231,7 +228,7 @@ class Node(Serializable):
         return self.graphicsNode.pos()  # QPointF
 
     @pos.setter
-    def pos(self, pos: Pos):
+    def pos(self, pos):
         if isinstance(pos, (list, tuple)):
             try:
                 x, y = pos
@@ -385,7 +382,7 @@ class Node(Serializable):
         """
         Safely remove this node.
         """
-        self.__logger.debug(f"Removing {self}")
+        logger.debug(f"Removing {self}")
         self.__logger.debug("Removing all edges connected to the node.")
         for socket in self.inputSockets + self.outputSockets:
             socket.removeAllEdges()
