@@ -9,10 +9,12 @@ import os
 from collections import OrderedDict
 from typing import Callable, List, Optional, cast
 
-from PySide2.QtGui import QDragEnterEvent, QDropEvent
-from PySide2.QtWidgets import QGraphicsItem
+from PySide6.QtGui import QDragEnterEvent, QDropEvent
+from PySide6.QtWidgets import QGraphicsItem
 
 from nodedge.edge import Edge
+from nodedge.elements.comment_element import CommentElement
+from nodedge.elements.element import Element
 from nodedge.graphics_node import GraphicsNode
 from nodedge.graphics_scene import GraphicsScene
 from nodedge.graphics_view import GraphicsView
@@ -20,9 +22,12 @@ from nodedge.node import Node
 from nodedge.scene_clipboard import SceneClipboard
 from nodedge.scene_coder import SceneCoder
 from nodedge.scene_history import SceneHistory
+from nodedge.scene_simulator import SceneSimulator
 from nodedge.serializable import Serializable
 from nodedge.utils import dumpException
 
+logger = logging.getLogger(__name__)
+
 
 class Scene(Serializable):
     """:class:`~nodedge.scene.Scene` class"""
@@ -42,9 +47,7 @@ class Scene(Serializable):
         super().__init__()
         self.nodes: List[Node] = []
         self.edges: List[Edge] = []
-
-        self.__logger = logging.getLogger(__file__)
-        self.__logger.setLevel(logging.INFO)
+        self.elements: List[Element] = []
 
         self.sceneWidth: int = 64000
         self.sceneHeight: int = 64000
@@ -52,6 +55,7 @@ class Scene(Serializable):
         self.history: SceneHistory = SceneHistory(self)
         self.clipboard: SceneClipboard = SceneClipboard(self)
         self.coder: SceneCoder = SceneCoder(scene=self)
+        self.simulator: SceneSimulator = SceneSimulator(self)
 
         self._isModified: bool = False
         self.isModified: bool = False
@@ -69,7 +73,7 @@ class Scene(Serializable):
 
         self.graphicsScene: GraphicsScene = GraphicsScene(self)
         self.graphicsScene.setScene(self.sceneWidth, self.sceneHeight)
-        self.graphicsScene.itemSelected.connect(self.onItemSelected)  # type: ignore
+        self.graphicsScene.itemSelected.connect(self.onItemSelected)
 
         # current filename assigned to this scene
         self.filename: Optional[str] = None
@@ -135,7 +139,7 @@ class Scene(Serializable):
         return ret
 
     @property
-    def selectedNodes(self) -> List[Node]:
+    def selectedNodes(self) -> List[GraphicsNode]:
         return [item for item in self.selectedItems if isinstance(item, GraphicsNode)]
 
     @property
@@ -277,6 +281,11 @@ class Scene(Serializable):
         """
         self.nodes.append(node)
 
+    def addElement(self):
+        element = CommentElement(self)
+        logger.info(f"Number of elements: {len(self.elements)}")
+        logger.info([e.graphicsElement.pos() for e in self.elements])
+
     def addEdge(self, edge: Edge):
         """Add :class:`~nodedge.edge.Edge` to this `Scene`
 
@@ -293,11 +302,24 @@ class Scene(Serializable):
         if nodeToRemove in self.nodes:
             self.nodes.remove(nodeToRemove)
         else:
-            self.__logger.warning(
+            logger.warning(
                 f"Trying to remove {nodeToRemove} from {self} but is it not in the "
                 f"node list. "
             )
 
+    def removeElement(self, elementToRemove: Element):
+        """Remove :class:`~nodedge.node.Node` from this `Scene`
+        :param elementToRemove: :class:`~nodedge.elements.element.Element` to be removed from this `Scene`
+        :type elementToRemove: :class:`~nodedge.elements.element.Element`
+        """
+        if elementToRemove in self.elements:
+            self.elements.remove(elementToRemove)
+        else:
+            logger.warning(
+                f"Trying to remove {elementToRemove} from {self} but is it not in the "
+                f"element list. "
+            )
+
     def removeEdge(self, edgeToRemove: Edge):
         """Remove :class:`~nodedge.edge.Edge` from this `Scene`
 
@@ -307,7 +329,7 @@ class Scene(Serializable):
         if edgeToRemove in self.edges:
             self.edges.remove(edgeToRemove)
         else:
-            self.__logger.warning(
+            logger.warning(
                 f"Trying to remove {edgeToRemove} from {self} but is it not is the "
                 f"edge list. "
             )
@@ -332,7 +354,7 @@ class Scene(Serializable):
         """
         with open(filename, "w") as file:
             file.write(json.dumps(self.serialize(), indent=4))
-            self.__logger.info(f"Saving to {filename} was successful.")
+            logger.info(f"Saving to {filename} was successful.")
 
             self.isModified = False
             self.filename = filename
@@ -349,7 +371,7 @@ class Scene(Serializable):
         with open(filename) as file:
             rawData = file.read()
             try:
-                data = json.loads(rawData, encoding="utf-8")
+                data = json.loads(rawData)
                 self.deserialize(data)
                 self.isModified = False
                 self.filename = filename
@@ -368,13 +390,18 @@ class Scene(Serializable):
         :return: data serialized in ``OrderedDict``
         :rtype: ``OrderedDict``
         """
-        nodes, edges = [], []
+        nodes, edges, elements = [], [], []
         for node in self.nodes:
             nodes.append(node.serialize())
 
         for edge in self.edges:
             edges.append(edge.serialize())
 
+        for element in self.elements:
+            elements.append(element.serialize())
+
+        simulator = self.simulator.serialize()
+
         return OrderedDict(
             [
                 ("id", self.id),
@@ -382,6 +409,8 @@ class Scene(Serializable):
                 ("sceneHeight", self.sceneHeight),
                 ("nodes", nodes),
                 ("edges", edges),
+                ("elements", elements),
+                ("simulator", simulator),
             ]
         )
 
@@ -412,7 +441,7 @@ class Scene(Serializable):
         try:
             if hashmap is None:
                 hashmap = {}
-            self.__logger.debug(f"Deserialize data: {data}")
+            logger.debug(f"Deserialize data: {data}")
             self.clear()
 
             if restoreId:
@@ -460,8 +489,31 @@ class Scene(Serializable):
             while allEdges:
                 edge = allEdges.pop()
                 edge.remove()
+
+            allElements = self.elements.copy()
+            elementsData = data.get("elements")
+            if elementsData is not None:
+                for elementData in elementsData:
+                    existingElement: Optional[Element] = None
+                    for element in allElements:
+                        if element.id == elementData["id"]:
+                            existingElement = element
+
+                    if not existingElement:
+                        CommentElement(self).deserialize(
+                            elementData, hashmap, restoreId
+                        )
+
+                while allElements:
+                    element = allElements.pop()
+                    element.remove()
+
+            simulatorData = data.get("simulator")
+            if simulatorData is not None:
+                self.simulator.deserialize(simulatorData)
             return True
         except Exception as e:
+
             dumpException(e)
             return False
 
